/*
 * Copyright (c) 2011-2013 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
{
}

 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <glib.h>

#include "connection_extension.h"
#include "net_connection_private.h"
#include "net_connection_mptcp_private.h"

EXPORT_API int connection_mptcp_is_supported(connection_h connection, bool* supported)
{
	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	*supported = _connection_libnet_mptcp_supported(connection);
	return CONNECTION_ERROR_NONE;
}

EXPORT_API int connection_mptcp_enable(connection_h connection, connection_mptcp_enable_e enable)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	if (enable <= CONNECTION_MPTCP_DISABLE
			|| enable > CONNECTION_MPTCP_ENABLE_SOCKOPT) {
		CONNECTION_LOG(CONNECTION_ERROR, "Use connection_mptcp_disable()");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_INVALID_PARAMETER;	//LCOV_EXCL_LINE
	}

	return _connection_libnet_mptcp_enable(connection, enable);
}

EXPORT_API int connection_mptcp_disable(connection_h connection)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	return _connection_libnet_mptcp_enable(connection, CONNECTION_MPTCP_DISABLE);
}

EXPORT_API int connection_mptcp_get_enabled(connection_h connection, connection_mptcp_enable_e* enable)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	if (enable == NULL) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_INVALID_PARAMETER;	//LCOV_EXCL_LINE
	}

	return _connection_libnet_mptcp_get_enabled(connection, enable);
}


EXPORT_API int connection_mptcp_set_path_manager(connection_h connection, connection_mptcp_path_manager_e pm)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	return _connection_libnet_mptcp_set_path_manager(connection, pm);
}

EXPORT_API int connection_mptcp_get_path_manager(connection_h connection, connection_mptcp_path_manager_e* pm)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	if (pm == NULL) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	return _connection_libnet_mptcp_get_path_manager(connection, pm);
}


EXPORT_API int connection_mptcp_set_scheduler(connection_h connection, connection_mptcp_scheduler_e scheduler)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	return _connection_libnet_mptcp_set_scheduler(connection, scheduler);
}

EXPORT_API int connection_mptcp_get_scheduler(connection_h connection, connection_mptcp_scheduler_e* scheduler)
{
	// check MPTCP support
	if (_connection_libnet_mptcp_supported(connection) == FALSE) {
		CONNECTION_LOG(CONNECTION_ERROR, "MPTCP is not supported");	//LCOV_EXCL_LINE
		return CONNECTION_ERROR_NOT_SUPPORTED;	//LCOV_EXCL_LINE
	}

	if (!(_connection_check_handle_validity(connection))) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	if (scheduler == NULL) {
		CONNECTION_LOG(CONNECTION_ERROR, "Invalid parameter");
		return CONNECTION_ERROR_INVALID_PARAMETER;
	}

	return _connection_libnet_mptcp_get_scheduler(connection, scheduler);
}


